@@ -16,32 +16,42 @@ from discord_slash.utils.manage_components import (
     create_select_option
 )
 
+from .errors import (
+    BadContent,
+    BadButtons,
+    NoTitle,
+    IncorrectDataType,
+    BadEmoji
+)
+
+
 async def Paginator(
     bot: commands.Bot,
-    ctx: SlashContext,
+    ctx: Union[SlashContext, commands.Context],
     pages: List[discord.Embed],
-    content: Optional[str] = None,
+    content: Optional[Union[str, List[str]]] = None,
     authorOnly: Optional[bool] = False,
     timeout: Optional[int] = None,
     disableAfterTimeout: Optional[bool] = True,
     deleteAfterTimeout: Optional[bool] = False,
     useSelect: Optional[bool] = True,
+    useButtons: Optional[bool] = True,
     useIndexButton: Optional[bool] = False,
     firstLabel: str = "",
     prevLabel: str = "",
     nextLabel: str = "",
     lastLabel: str = "",
     firstEmoji: Optional[
-        Union[discord.emoji.Emoji, discord.partial_emoji.PartialEmoji, dict]
+        Union[discord.Emoji, discord.PartialEmoji, dict, bytes]
     ] = "⏮️",
     prevEmoji: Optional[
-        Union[discord.emoji.Emoji, discord.partial_emoji.PartialEmoji, dict]
+        Union[discord.Emoji, discord.PartialEmoji, dict, bytes]
     ] = "◀",
     nextEmoji: Optional[
-        Union[discord.emoji.Emoji, discord.partial_emoji.PartialEmoji, dict]
+        Union[discord.Emoji, discord.PartialEmoji, dict, bytes]
     ] = "▶",
     lastEmoji: Optional[
-        Union[discord.emoji.Emoji, discord.partial_emoji.PartialEmoji, dict]
+        Union[discord.Emoji, discord.PartialEmoji, dict, bytes]
     ] = "⏭️",
     indexStyle: Optional[Union[ButtonStyle, int]] = 3,
     firstStyle: Optional[Union[ButtonStyle, int]] = 1,
@@ -58,6 +68,7 @@ async def Paginator(
     :param disableAfterTimeout: disables components after timeout
     :param deleteAfterTimeout: deletes components after timeout
     :param useSelect: uses select
+    :param useButtons: uses buttons
     :param useIndexButton: uses index button
     :param firstLabel: label of first page button
     :param prevLabel: label of previous page button
@@ -74,6 +85,66 @@ async def Paginator(
     :param lastStyle: colo[u]r of last button
     """
     top = len(pages)  # limit of the paginator
+    multiContent = False
+
+    if not isinstance(bot, commands.Bot):
+        raise IncorrectDataType("bot", "commands.Bot", bot)
+    if not isinstance(ctx, SlashContext) and not isinstance(ctx, commands.Context):
+        raise IncorrectDataType("ctx", "SlashContext or commands.Context", ctx)
+    if isinstance(content, list):
+        if len(content) < top:
+            content = content[0]
+            if not isinstance(content, str):
+                raise BadContent(content)
+        else:
+            content = content[:top]
+            for s in content:
+                if not isinstance(s, str):
+                    raise BadContent(content)
+            multiContent = True
+    elif not isinstance(content, str):
+        if content != None:
+            raise BadContent(content)
+    if not isinstance(authorOnly, bool):
+        raise IncorrectDataType("authorOnly", "bool", authorOnly)
+    if not isinstance(timeout, int):
+        if timeout != None:
+            raise IncorrectDataType("timeout", "int", timeout)
+    if not isinstance(disableAfterTimeout, bool):
+        raise IncorrectDataType("disableAfterTimeout", "bool", disableAfterTimeout)
+    if not isinstance(deleteAfterTimeout, bool):
+        raise IncorrectDataType("deleteAfterTimeout", "bool", deleteAfterTimeout)
+    if not isinstance(useButtons, bool):
+        raise IncorrectDataType("useButtons", "bool", useButtons)
+    if not isinstance(authorOnly, bool):
+        raise IncorrectDataType("useSelect", "bool", useSelect)
+    if not isinstance(useIndexButton, bool):
+        raise IncorrectDataType("useIndexButton", "bool", useIndexButton)
+    if not isinstance(firstLabel, str):
+        raise IncorrectDataType("firstLabel", "str", firstLabel)
+    if not isinstance(prevLabel, str):
+        raise IncorrectDataType("prevLabel", "str", firstLabel)
+    if not isinstance(nextLabel, str):
+        raise IncorrectDataType("nextLabel", "str", firstLabel)
+    if not isinstance(lastLabel, str):
+        raise IncorrectDataType("lastLabel", "str", firstLabel)
+    emojis = [firstEmoji, prevEmoji, nextEmoji, lastEmoji]
+    for emoji in emojis:
+        num = emojis.index(emoji) + 1
+        if not isinstance(emoji, discord.Emoji) and not isinstance(emoji, discord.PartialEmoji) and not isinstance(emoji, dict) and not isinstance(emoji, str):
+            raise BadEmoji(num)
+    if not isinstance(indexStyle, ButtonStyle) and not isinstance(indexStyle, int):
+        raise IncorrectDataType("indexStyle", "ButtonStyle or int", indexStyle)
+    if not isinstance(firstStyle, ButtonStyle) and not isinstance(firstStyle, int):
+        raise IncorrectDataType("firstLabel", "ButtonStyle or int", firstStyle)
+    if not isinstance(prevStyle, ButtonStyle) and not isinstance(prevStyle, int):
+        raise IncorrectDataType("prevLabel", "ButtonStyle or int", prevStyle)
+    if not isinstance(nextStyle, ButtonStyle) and not isinstance(nextStyle, int):
+        raise IncorrectDataType("nextLabel", "ButtonStyle or int", nextStyle)
+    if not isinstance(lastStyle, ButtonStyle) and not isinstance(lastStyle, int):
+        raise IncorrectDataType("lastLabel", "ButtonStyle or int", lastStyle)
+        
+    
     bid = random.randint(10000, 99999)  # base of button id
     index = 0  # starting page
     controlButtons = [
@@ -122,22 +193,34 @@ async def Paginator(
         pageNum = pages.index(i) + 1
         try:
             title = i.title
-            title = (title[:18] + "...") if len(title) > 21 else title
-            select_options.append(create_select_option(f"{pageNum}: {title}", value=f"{pageNum}"))
+            if title == discord.Embed.Empty:
+                select_options.append(create_select_option(f"{pageNum}: Title not found", value=f"{pageNum}"))
+                NoTitle(pageNum)
+            else:
+                title = (title[:93] + "...") if len(title) > 96 else title
+                select_options.append(create_select_option(f"{pageNum}: {title}", value=f"{pageNum}"))
         except Exception:
             select_options.append(create_select_option(f"{pageNum}: Title not found", value=f"{pageNum}"))
+            NoTitle(pageNum)
     select = create_select(
         options=select_options,
         placeholder=f"Page {index+1}/{top}",
         min_values=1,
         max_values=1,
     )
+    if useIndexButton == True and useButtons == False:
+        BadButtons("Index button cannot be used with useButtons=False!")
+    useIndexButton = False if useButtons == False else useIndexButton
     if useIndexButton == False:
         controlButtons.pop(2)
     selectControls = create_actionrow(select)
     buttonControls = create_actionrow(*controlButtons)
-    components = [selectControls, buttonControls] if useSelect == True else [buttonControls]
-    msg = await ctx.send(content=content, embed=pages[0], components=components)
+    components = []
+    if useSelect == True:
+        components.append(selectControls)
+    if useButtons == True:
+        components.append(buttonControls)
+    msg = await ctx.send(content=content[0] if multiContent else content, embed=pages[0], components=components)
     # handling the interaction
     tmt = True  # stop listening when timeout expires
     while tmt:
@@ -184,7 +267,7 @@ async def Paginator(
                         "placeholder"
                     ] = f"Page {index+1}/{top}"
                 await button_context.edit_origin(
-                    content=content, embed=pages[index], components=components
+                    content=content[index] if multiContent else content, embed=pages[index], components=components
                 )
             # Handling previous button
             if button_context.component_id == f"{bid}-prev" and index > 0:
@@ -207,7 +290,7 @@ async def Paginator(
                         "placeholder"
                     ] = f"Page {index+1}/{top}"
                 await button_context.edit_origin(
-                    content=content, embed=pages[index], components=components
+                    content=content[index] if multiContent else content, embed=pages[index], components=components
                 )
             # handling next button
             if button_context.component_id == f"{bid}-next" and index < top - 1:
@@ -230,7 +313,7 @@ async def Paginator(
                         "placeholder"
                     ] = f"Page {index+1}/{top}"
                 await button_context.edit_origin(
-                    content=content, embed=pages[index], components=components
+                    content=content[index] if multiContent else content, embed=pages[index], components=components
                 )
             # handling last button
             if button_context.component_id == f"{bid}-last" and index < top - 1:
@@ -252,46 +335,47 @@ async def Paginator(
                         "placeholder"
                     ] = f"Page {index+1}/{top}"
                 await button_context.edit_origin(
-                    content=content, embed=pages[index], components=components
+                    content=content[index] if multiContent else content, embed=pages[index], components=components
                 )
             # handling select
             if button_context.component_type == 3:
                 index = int(button_context.selected_options[0]) - 1
-                if index == 0:
-                    buttonControls["components"][0][
-                        "disabled"
-                    ] = True  # Disables the first button
-                    buttonControls["components"][1][
-                        "disabled"
-                    ] = True  # Disables the previous button
-                    buttonControls["components"][3 if useIndexButton == True else 2]["disabled"] = False  # Enables Next Button
-                    buttonControls["components"][4 if useIndexButton == True else 3]["disabled"] = False  # Enables Last Button
-                elif index == top - 1:
-                    buttonControls["components"][3 if useIndexButton == True else 2][
-                        "disabled"
-                    ] = True  # disables the next button
-                    buttonControls["components"][4 if useIndexButton == True else 3][
-                        "disabled"
-                    ] = True  # disables the last button
-                    buttonControls["components"][0]["disabled"] = False  # enables first button
-                    buttonControls["components"][1]["disabled"] = False  # enables previous button
-                else:
-                    buttonControls["components"][3 if useIndexButton == True else 2][
-                        "disabled"
-                    ] = False # enables the next button
-                    buttonControls["components"][4 if useIndexButton == True else 3][
-                        "disabled"
-                    ] = False # enables the last button
-                    buttonControls["components"][0]["disabled"] = False # enables first button
-                    buttonControls["components"][1]["disabled"] = False # enables previous button
-                if useIndexButton == True:
-                    buttonControls["components"][2][
-                        "label"
-                    ] = f"Page {index+1}/{top}"  # updates the index
+                if useButtons == True:
+                    if index == 0:
+                        buttonControls["components"][0][
+                            "disabled"
+                        ] = True  # Disables the first button
+                        buttonControls["components"][1][
+                            "disabled"
+                        ] = True  # Disables the previous button
+                        buttonControls["components"][3 if useIndexButton == True else 2]["disabled"] = False  # Enables Next Button
+                        buttonControls["components"][4 if useIndexButton == True else 3]["disabled"] = False  # Enables Last Button
+                    elif index == top - 1:
+                        buttonControls["components"][3 if useIndexButton == True else 2][
+                            "disabled"
+                        ] = True  # disables the next button
+                        buttonControls["components"][4 if useIndexButton == True else 3][
+                            "disabled"
+                        ] = True  # disables the last button
+                        buttonControls["components"][0]["disabled"] = False  # enables first button
+                        buttonControls["components"][1]["disabled"] = False  # enables previous button
+                    else:
+                        buttonControls["components"][3 if useIndexButton == True else 2][
+                            "disabled"
+                        ] = False # enables the next button
+                        buttonControls["components"][4 if useIndexButton == True else 3][
+                            "disabled"
+                        ] = False # enables the last button
+                        buttonControls["components"][0]["disabled"] = False # enables first button
+                        buttonControls["components"][1]["disabled"] = False # enables previous button
+                    if useIndexButton == True:
+                        buttonControls["components"][2][
+                            "label"
+                        ] = f"Page {index+1}/{top}"  # updates the index
                 if useSelect == True:
                     selectControls["components"][0][
                         "placeholder"
                     ] = f"Page {index+1}/{top}"
                 await button_context.edit_origin(
-                    content=content, embed=pages[index], components=components
+                    content=content[index] if multiContent else content, embed=pages[index], components=components
                 )
